OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "이 공유 파일은 다운로드 권한이 없으며, 보안 열람에 의해 보호되고 있을 수 있습니다. 파일 소유자에게 연락하여 권한을 요청하거나 다른 뷰어를 이용하십시오.",
    "Open in PDF Viewer" : "PDF 뷰어로 열기",
    "Close" : "닫기"
},
"nplurals=1; plural=0;");
