OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "ไฟล์ที่แชร์นี้ไม่มีสิทธิ์ในการดาวน์โหลดและอาจได้รับการปกป้องโดยการดูที่ปลอดภัย โปรดติดต่อเจ้าของไฟล์เพื่อขออนุญาตหรือใช้โปรแกรมดูอื่น",
    "Open in PDF Viewer" : "เปิดด้วย PDF Viewer",
    "Close" : "ปิด"
},
"nplurals=1; plural=0;");
