OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly proteced by secure view, please contact the owner of the file for granting permission or use a different viewer." : "هذا الملف المشترك ليس لديه إذن تنزيل وربما يكون محميًا بواسطة طريقة عرض آمنة ، يرجى الاتصال بمالك الملف لمنح الإذن أو استخدام عارض مختلف.",
    "Open in PDF Viewer" : "فتح في عارض PDF",
    "Close" : "إغلاق"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
