OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "已分享的檔案沒有下載權限，可能受安全視圖保護，請聯繫檔案所有者授予權限或使用其他查看器。",
    "Open in PDF Viewer" : "開啟PDF檢視器",
    "Close" : "關閉"
},
"nplurals=1; plural=0;");
