<?php
 $config = new OC\CodingStandard\Config();
 $config
    ->setUsingCache(true)
    ->getFinder()
    ->exclude('vendor')
    ->exclude('vendor-bin')
    ->exclude('l10n')
    ->in(__DIR__);
 return $config;
