OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "ໄຟລ໌ທີ່ແບ່ງປັນນີ້ບໍ່ໄດ້ຮັບອະນຸຍາດໃຫ້ດາວໂຫຼດ ແລະ ອາດຈະຖືກປ້ອງກັນດ້ວຍລະບົບການເບິ່ງແບບປອດໄພ, ກະລຸນາຕິດຕໍ່ເຈົ້າຂອງໄຟລ໌ເພື່ອຂໍອະນຸຍາດ ຫຼື ໃຊ້ເຄື່ອງມືເປີດເບິ່ງອື່ນ.",
    "Open in PDF Viewer" : "ເປີດໃນເຄື່ອງມືເບິ່ງ PDF",
    "Close" : "ປິດ"
},
"nplurals=1; plural=0;");
