OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "Kjo kartelë e përbashkët s’ka leje shkarkimi dhe ka mundësi të mbrohet me parje të siguruar, ju lutemi, lidhuni me të zotin e kartelës që t’ju akordojë leje, ose përdorni një parës tjetër.",
    "Open in PDF Viewer" : "Hape në Parës PDF-sh",
    "Close" : "Mbylle"
},
"nplurals=2; plural=(n != 1);");
