OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "Este archivo compartido no tiene permiso de descarga y posiblemente esté protegido por una vista segura, comuníquese con el propietario del archivo para otorgar el permiso o use un visor diferente.",
    "Open in PDF Viewer" : "Abrir en PDF Viewer",
    "Close" : "Cerrar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
