OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "Este arquivo compartilhado não tem permissão para ser baixado e possivelmente está protegido por visualização segura. Entre em contato com o proprietário do arquivo para conceder permissão ou use um visualizador diferente. ",
    "Open in PDF Viewer" : "Abrir no visualizador de PDF",
    "Close" : "Fechar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
