OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly proteced by secure view, please contact the owner of the file for granting permission or use a different viewer." : "Este ficheiro compartido non ten permiso de descarga e posibelmente estea protexido por unha vista segura. Póñase en contacto co propietario do ficheiro para obter o permiso ou use outro visor.",
    "Open in PDF Viewer" : "Abrir no visor PDF",
    "Close" : "Pechar"
},
"nplurals=2; plural=(n != 1);");
