OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "На эти общие файлы не разрешения на скачивание и возможно они защищены безопасным просмотром, пожалуйста свяжитесь с владельцем файла для получения разрешения или используйте другое средство просмотра.",
    "Open in PDF Viewer" : "Открыть в просмотре PDF",
    "Close" : "Закрыть"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
