OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "此共享文件没有下载权限，可能受安全视图保护，请联系文件所有者授予权限或使用其他查看器。",
    "Open in PDF Viewer" : "在 PDF 查看器中打开",
    "Close" : "关闭"
},
"nplurals=1; plural=0;");
