OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "この共有ファイルはダウンロード権限がなく、セキュアビューで保護されている可能性があります。ファイルの所有者に連絡して、権限を付与するか、別のビューアを使用してください。",
    "Open in PDF Viewer" : "PDFビューアで開く",
    "Close" : "閉じる"
},
"nplurals=1; plural=0;");
