OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "Diese freigegebene Datei hat keine Download-Berechtigung und ist möglicherweise durch eine sichere Ansicht geschützt. Wenden Sie sich bitte an den Eigentümer der Datei, um die Berechtigung zu erteilen, oder verwenden Sie einen anderen Viewer.",
    "Open in PDF Viewer" : "Mit PDF Viewer öffnen",
    "Close" : "Schließen"
},
"nplurals=2; plural=(n != 1);");
