OC.L10N.register(
    "files_pdfviewer",
    {
    "This shared file does not have download permission and is possibly protected by secure view, please contact the owner of the file for granting permission or use a different viewer." : "Bu paylaşılan dosyanın indirme izni yok ve muhtemelen güvenli görünümle korunuyor, lütfen izin vermek için dosyanın sahibiyle iletişime geçin veya farklı bir görüntüleyici kullanın.",
    "Open in PDF Viewer" : "PDF Görüntüleyicide Aç",
    "Close" : "Kapat"
},
"nplurals=2; plural=(n > 1);");
